@@ -13,7 +13,6 @@ from sys import exit, stdout
 
 from humanize import naturaldelta
 from slixmpp import ClientXMPP
-from slixmpp.exceptions import XMPPError
 
 
 class SimpleMessage:
@@ -140,6 +139,7 @@ class Bot(ClientXMPP):
         config_file_path = Path(self.CONFIG_FILE).absolute()
 
         if not exists(config_file_path) and stdout.isatty():
+            self.log.info(f"Did not find {config_file_path}")
             self.generate_config_interactively()
 
         if exists(config_file_path):
@@ -202,6 +202,11 @@ class Bot(ClientXMPP):
         self.add_event_handler("groupchat_invite", self.group_invite)
         self.add_event_handler("message", self.direct_message)
         self.add_event_handler("groupchat_message", self.group_message)
+        self.add_event_handler("message_error", self.error_message)
+
+    def error_message(self, message):
+        _message = SimpleMessage(message)
+        self.log.error(f"Received error message: {_message.body}")
 
     def direct_message(self, message):
         """Handle message event."""
@@ -267,7 +272,6 @@ class Bot(ClientXMPP):
         self.register_plugin("xep_0030")  # Service Discovery
         self.register_plugin("xep_0045")  # Multi-User Chat
         self.register_plugin("xep_0199")  # XMPP Ping
-
         self.register_plugin("xep_0084")  # User Avatar
 
     def run(self):
@@ -315,8 +319,10 @@ class Bot(ClientXMPP):
                 self.reply(self.help, **kwargs)
             except AttributeError:
                 self.reply("No help found 🤔️", **kwargs)
+        elif command == "bots" and "room" in kwargs:
+            self.reply("o/", **kwargs)
         else:
-            self.log.error(f"'{command}' direct command is not recognised")
+            self.log.error(f"'{command}' command is not recognised")
 
 
 class EchoBot(Bot):
